==> beetl-3.1.6.RELEASE-sources.jar: org/beetl/core/statement/Program.java <==
/*
 [The "BSD license"]
 Copyright (c) 2011-2019  闲大赋 (李家智)
 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 1. Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
 2. Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in the
     documentation and/or other materials provided with the distribution.
 3. The name of the author may not be used to endorse or promote products
     derived from this software without specific prior written permission.

 THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package org.beetl.core.statement;

import org.beetl.core.Context;
import org.beetl.core.GroupTemplate;
import org.beetl.core.Resource;

/**
 * 脚本运行程序
 * @author joelli
 *
 */
public class Program
{
	// 模板的所有脚本语句
	public ProgramMetaData metaData = null;
	public Resource res = null;
	public GroupTemplate gt = null;


	public Program()
	{

	}

	public void execute(Context ctx)
	{

		if (metaData.hasGoto)
		{
			runWitchGoCheck(metaData.statements,ctx);
		}
		else
		{
			run(metaData.statements,ctx);
		}

	}

	protected  final void  run( Statement[] statements,Context ctx ){
		int len = statements.length;
		for(int i=0;i<len;i++){
			statements[i].execute(ctx);
		}
	}

	protected  final  void  runWitchGoCheck( Statement[] statements,Context ctx ){
		int len = statements.length;
		for(int i=0;i<len;i++){
			statements[i].execute(ctx);
			if (ctx.gotoFlag == IGoto.RETURN)
			{
				return;
			}
		}
	}




}

==> beetl-3.3.2.RELEASE-sources.jar: org/beetl/core/statement/Program.java <==
/*
 [The "BSD license"]
 Copyright (c) 2011-2020  闲大赋 (李家智)
 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 1. Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
 2. Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in the
     documentation and/or other materials provided with the distribution.
 3. The name of the author may not be used to endorse or promote products
     derived from this software without specific prior written permission.

 THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package org.beetl.core.statement;

import org.beetl.core.Context;
import org.beetl.core.GroupTemplate;
import org.beetl.core.Resource;

/**
 * 脚本运行程序
 *
 * @author xiandafu
 */
public class Program {
    // 模板的所有脚本语句
    public ProgramMetaData metaData = null;
    public Resource res = null;
    public GroupTemplate gt = null;

    public Program() {

    }

    public void execute(Context ctx) {

        if (metaData.hasGoto) {
            runWitchGoCheck(metaData.statements, ctx);
        } else {
            run(metaData.statements, ctx);
        }

    }

    protected final void run(Statement[] statements, Context ctx) {
        for (Statement statement : statements) {
            statement.execute(ctx);
        }
    }

    protected final void runWitchGoCheck(Statement[] statements, Context ctx) {
        for (Statement statement : statements) {
            statement.execute(ctx);
            if (ctx.gotoFlag == IGoto.RETURN) {
                return;
            }
        }
    }

}
